﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Controls;
using DlhSoft.Windows.Data;

namespace GanttChartViewCriticalPathSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        // Drawing objects to be used for highlighting the critical path.
        private static readonly Brush criticalPathFill = new LinearGradientBrush { StartPoint = new Point(0, 0), EndPoint = new Point(0, 1), GradientStops = new GradientStopCollection { new GradientStop(Colors.Transparent, 0), new GradientStop(Colors.Pink, 0.25), new GradientStop(Colors.Red, 1) } };
        private static readonly Brush criticalPathStroke = Brushes.Red;

        // Critical path task collection.
        private List<Task> criticalPathTasks;

        // Determine and highlight critical path.
        private void HighlightCriticalPathMenuItem_Checked(object sender, RoutedEventArgs e)
        {
            // Get critical task collection.
            criticalPathTasks = GanttChartView.GetCriticalTasks();
            // Set the control as read only when highlighting the critical path.
            GanttChartView.IsReadOnly = true;
            // Set critical path fill and stroke for critical tasks.
            foreach (Task task in criticalPathTasks)
            {
                TaskItem taskItem = task.Item as TaskItem;
                if (taskItem != null)
                {
                    taskItem.SetValue(GanttChartView.StandardBarFillProperty, criticalPathFill);
                    taskItem.SetValue(GanttChartView.StandardBarStrokeProperty, criticalPathStroke);
                }
            }
            // Apply item appearance in the control.
            GanttChartView.IsItemAppearanceApplied = true;
        }
        private void HighlightCriticalPathMenuItem_Unchecked(object sender, RoutedEventArgs e)
        {
            // Stop applying item appearance in the control.
            GanttChartView.IsItemAppearanceApplied = false;
            // Clear critical path fill and stroke for critical tasks.
            foreach (Task task in criticalPathTasks)
            {
                TaskItem taskItem = task.Item as TaskItem;
                if (taskItem != null)
                {
                    taskItem.ClearValue(GanttChartView.StandardBarStrokeProperty);
                    taskItem.ClearValue(GanttChartView.StandardBarFillProperty);
                }
            }
            // Reset the control as not read only when highlighting the critical path is cleared.
            GanttChartView.IsReadOnly = false;
            // Clear critical task collection.
            criticalPathTasks = null;
        }
    }
}
